==> web-6.0.0.tgz: package/lib/combo/ComboInp.js <==
import * as React from "react";
import { SvgIcon } from "../my-icon/index";
class ComboInp extends React.PureComponent {
    constructor() {
        super(...arguments);
        this.state = {};
        this.clickFn = (e) => {
            e.stopPropagation();
            this.props.clearFn();
        };
    }
    getSlideIcon(noicon, drop) {
        return !noicon ? (React.createElement(SvgIcon, { className: `arrow-${drop ? "down" : "up"}` })) : undefined;
    }
    getTit(tit) {
        return (React.createElement("span", { className: "combo-inp-tit" }, tit));
    }
    getClearCom(show) {
        return show ? (React.createElement("span", { onClick: this.clickFn },
            React.createElement(SvgIcon, { className: `close` }))) : undefined;
    }
    render() {
        const { selected, slideFn, tit, formatterVal, noicon, drop, noRequire, ableClear } = this.props;
        const status = noRequire ? "" : selected.size ? "" : "no-fill";
        const clearStatus = ableClear && selected.size ? true : false;
        return (React.createElement("div", { className: `m-combo-inp ${status}`, onClick: slideFn },
            React.createElement("div", { className: "combo-value" }, selected.size ? formatterVal(selected) : this.getTit(tit)),
            this.getSlideIcon(noicon, drop),
            this.getClearCom(clearStatus)));
    }
}
ComboInp.defaultProps = {
    formatterVal: (seleted) => {
        return seleted.map(val => val.text).join("，");
    },
};
export default ComboInp;

==> web-8.0.1.tgz: package/lib/combo/ComboInp.js <==
import * as React from "react";
import { SvgIcon } from "../my-icon/index";
class ComboInp extends React.PureComponent {
    constructor() {
        super(...arguments);
        this.state = {};
        this.clickFn = (e) => {
            e.stopPropagation();
            this.props.clearFn();
        };
    }
    getSlideIcon(noicon, drop) {
        return !noicon ? (React.createElement(SvgIcon, { className: `arrow-${drop ? "down" : "up"}` })) : undefined;
    }
    getTit(tit) {
        return (React.createElement("span", { className: "combo-inp-tit" }, tit));
    }
    getClearCom(show) {
        return show ? (React.createElement("span", { onClick: this.clickFn },
            React.createElement(SvgIcon, { className: `close` }))) : undefined;
    }
    render() {
        const { selected, slideFn, tit, formatterVal, noicon, drop, noRequire, ableClear } = this.props;
        const status = noRequire ? "" : selected.size ? "" : "no-fill";
        const clearStatus = ableClear && selected.size ? true : false;
        return (React.createElement("div", { className: `m-combo-inp ${status}`, onClick: slideFn },
            React.createElement("div", { className: "combo-value" }, selected.size ? formatterVal(selected) : this.getTit(tit)),
            this.getClearCom(clearStatus),
            this.getSlideIcon(noicon, drop)));
    }
}
ComboInp.defaultProps = {
    formatterVal: (seleted) => {
        return seleted.map(val => val.text).join("，");
    },
};
export default ComboInp;
